<?php
/**
 * @file
 * Twitter tracker block
 */

class GoogleAnalyticsTracker extends BeanPlugin {

  /**
   * Declares default block settings.
   */
  public function values() {
    $values = parent::values();
    $values['id'] = 0;
    $values['event'] = 'pageview';
    return $values;
  }

  /**
   * Builds extra settings for the block edit form.
   */
  public function form($bean, $form, &$form_state) {

    $form = array();

    $form['id'] = array(
      '#type' => 'textfield',
      '#title' => t('The Google Analytics tracking ID.'),
      '#description' => t("This identifier can be found in the code Google Analytics provides on the line \"ga('create', 'XX-XXXXX-X', 'auto');\""),
      '#required' => TRUE,
      '#default_value' => $bean->id,
    );

    // Choose from the available analytics.js hit types.
    // @see https://developers.google.com/analytics/devguides/collection/analyticsjs/field-reference#hitType
    $form['event'] = array(
      '#type' => 'select',
      '#options' => array(
        'pageview' => t('View Content'),
        'screenview' => t('Screen View'),
        'event' => t('Event'),
        'transaction' => t('Transaction'),
        'item' => t('Item'),
        'social' => t('Social'),
        'exception' => t('Exception'),
        'timing' => t('Timing'),
      ),
      '#default_value' => $bean->event,
      '#required' => FALSE,
      '#multiple' => FALSE,
    );

    return $form;
  }

  /**
   * Displays the bean.
   */
  public function view($bean, $content, $view_mode = 'default', $langcode = NULL) {
    $values = array(
      '#theme' => 'google_analytics_tracker',
      '#cache' => DRUPAL_CACHE_GLOBAL,
      'bean' => $content['bean'], // Needed by moriarty_preprocess_block
      'id' => $bean->id,
      'event' => $bean->event,
    );
    return $values;
  }
}
